import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i0 from '@angular/core';
import { Directive, Input, HostListener, Component, ViewChild, NgModule } from '@angular/core';
import { timer } from 'rxjs';

class TextScrollDirective {
    constructor(renderer2, elementRef) {
        this.renderer2 = renderer2;
        this.elementRef = elementRef;
    }
    mouseenter() {
        this.scroll();
    }
    mouseleave() {
        this.unScroll();
    }
    ngOnInit() {
        if (!this.speed) {
            this.speed = 1000;
        }
        const textScrollElement = this.elementRef.nativeElement;
        this.renderer2.setStyle(textScrollElement, 'whiteSpace', 'nowrap');
        this.renderer2.setStyle(textScrollElement, 'overflow', 'hidden');
        this.renderer2.setStyle(textScrollElement, 'textOverflow', 'ellipsis');
        this.renderer2.setStyle(textScrollElement, 'transition', `transform linear ${this.speed}ms`);
        this.renderer2.setStyle(textScrollElement.parentNode, 'overflow', 'hidden');
    }
    scroll() {
        const textScrollElement = this.elementRef.nativeElement;
        const childElement = textScrollElement.children[0];
        if (childElement && childElement.offsetWidth >= textScrollElement.clientWidth) {
            this.renderer2.setStyle(textScrollElement, 'transform', `translateX(${textScrollElement.clientWidth - childElement.offsetWidth}px)`);
            this.renderer2.setStyle(textScrollElement, 'overflow', 'visible');
            this.renderer2.setStyle(textScrollElement, 'textOverflow', 'unset');
        }
    }
    unScroll() {
        const textScrollElement = this.elementRef.nativeElement;
        this.renderer2.setStyle(textScrollElement, 'transform', 'translateX(0)');
        this.renderer2.setStyle(textScrollElement, 'overflow', 'hidden');
        this.renderer2.setStyle(textScrollElement, 'textOverflow', 'ellipsis');
    }
}
TextScrollDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: TextScrollDirective, deps: [{ token: i0.Renderer2 }, { token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive });
TextScrollDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.0", type: TextScrollDirective, selector: "[textScroll]", inputs: { speed: "speed" }, host: { listeners: { "mouseover": "mouseenter()", "mouseleave": "mouseleave()" } }, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: TextScrollDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[textScroll]'
                }]
        }], ctorParameters: function () { return [{ type: i0.Renderer2 }, { type: i0.ElementRef }]; }, propDecorators: { speed: [{
                type: Input
            }], mouseenter: [{
                type: HostListener,
                args: ['mouseover']
            }], mouseleave: [{
                type: HostListener,
                args: ['mouseleave']
            }] } });

class TextDisplayComponent {
}
TextDisplayComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: TextDisplayComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
TextDisplayComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.0", type: TextDisplayComponent, selector: "text-display", inputs: { text: "text" }, ngImport: i0, template: "<div class=\"container\">\r\n  <div textScroll class=\"text\">\r\n    <ng-container *ngIf=\"text; else elementTemplate\">\r\n      <span>{{ text }}</span>\r\n    </ng-container>\r\n\r\n    <ng-template #elementTemplate>\r\n      <ng-content select=\"[text]\"></ng-content>\r\n    </ng-template>\r\n  </div>\r\n</div>\r\n", styles: [".container{width:100%;height:100%}.text{text-align:left;width:100%;height:100%}\n"], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: TextScrollDirective, selector: "[textScroll]", inputs: ["speed"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: TextDisplayComponent, decorators: [{
            type: Component,
            args: [{ selector: 'text-display', template: "<div class=\"container\">\r\n  <div textScroll class=\"text\">\r\n    <ng-container *ngIf=\"text; else elementTemplate\">\r\n      <span>{{ text }}</span>\r\n    </ng-container>\r\n\r\n    <ng-template #elementTemplate>\r\n      <ng-content select=\"[text]\"></ng-content>\r\n    </ng-template>\r\n  </div>\r\n</div>\r\n", styles: [".container{width:100%;height:100%}.text{text-align:left;width:100%;height:100%}\n"] }]
        }], propDecorators: { text: [{
                type: Input
            }] } });

class TextReadComponent {
    constructor(elementRef, renderer2) {
        this.elementRef = elementRef;
        this.renderer2 = renderer2;
        this.rows = [];
        this.reading = false;
        this.revealed = true;
        this.timerSubscription = null;
    }
    start() {
        this.refresh();
        this.revealed = false;
        timer(0).subscribe(() => {
            if (this.overlay) {
                this.renderer2.addClass(this.overlay.nativeElement, 'read');
                this.renderer2.removeClass(this.overlay.nativeElement, 'reveal');
                this.reading = true;
            }
            if (this.speed) {
                this.timerSubscription = timer(this.speed).subscribe(() => {
                    this.reveal();
                });
            }
        });
    }
    reveal() {
        this.refresh();
        this.revealed = true;
        if (this.overlay) {
            this.renderer2.addClass(this.overlay.nativeElement, 'reveal');
            this.renderer2.removeClass(this.overlay.nativeElement, 'read');
            this.reading = false;
        }
        if (this.timerSubscription) {
            this.timerSubscription.unsubscribe();
            this.timerSubscription = null;
        }
    }
    restart() {
        this.reveal();
        this.start();
    }
    ngOnInit() {
        if (!this.relativeTo) {
            throw new Error(`text-read component, [relativeTo] attribute is required`);
        }
        if (!this.rowHeight) {
            throw new Error(`text-read component, [rowHeight] attribute is required`);
        }
        if (!this.cursorClass) {
            this.cursorClass = 'cursor-white';
        }
        if (!this.overlayClass) {
            this.overlayClass = 'overlay-black';
        }
        if (!this.speed) {
            this.speed = 1000;
        }
        this.refresh();
    }
    ngAfterViewInit() {
        if (this.overlay && this.overlayClass) {
            this.renderer2.addClass(this.overlay.nativeElement, this.overlayClass);
        }
    }
    refresh() {
        if (this.relativeTo && this.rowHeight) {
            const rowCount = Math.ceil(this.relativeTo.clientHeight / this.rowHeight);
            if (rowCount) {
                this.rows = Array(rowCount).fill(0).map((_x, i) => i);
            }
        }
        if (this.overlay && this.overlayClass) {
            this.renderer2.removeClass(this.overlay.nativeElement, this.overlayClass);
        }
    }
}
TextReadComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: TextReadComponent, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }], target: i0.ɵɵFactoryTarget.Component });
TextReadComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.0", type: TextReadComponent, selector: "text-read", inputs: { hideCursor: "hideCursor", cursorClass: "cursorClass", overlayClass: "overlayClass", relativeTo: "relativeTo", rowHeight: "rowHeight", speed: "speed", textLength: "textLength" }, viewQueries: [{ propertyName: "overlay", first: true, predicate: ["overlay"], descendants: true }], ngImport: i0, template: "<ng-container *ngIf=\"rowHeight && speed && !revealed\">\r\n  <div #overlay class=\"overlay\">\r\n    <div class=\"container\">\r\n      <div *ngFor=\"let rowIndex of rows\" [style.height.px]=\"rowHeight\" [style.top.px]=\"rowHeight * rowIndex\"\r\n        [style.animationDuration]=\"(speed / rows.length) + 'ms'\"\r\n        [style.animationDelay]=\"(speed * rowIndex / rows.length) + 'ms'\" [classList]=\"overlayClass + ' row'\">\r\n        <div *ngIf=\"!hideCursor\" [style.animationDuration]=\"(speed / rows.length / 40) + 'ms'\"\r\n          [classList]=\"cursorClass + ' row-cursor'\"></div>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</ng-container>\r\n", styles: ["@keyframes read{0%{width:100%}to{width:0}}@keyframes blink{0%{opacity:0}to{opacity:1}}.overlay-black{background-color:#000}.overlay{position:absolute;left:0;top:0;z-index:1;width:100%;height:100%}.container{position:relative;overflow:hidden;width:100%;height:100%}.row{position:absolute;right:0;z-index:1;width:calc(100% + 2px)}.reveal .row{width:0}.read .row{animation-name:read;animation-timing-function:linear;animation-fill-mode:forwards}.cursor-white{background:white}.row-cursor{width:2px;height:100%;animation-name:blink;animation-timing-function:linear;animation-iteration-count:infinite}\n"], dependencies: [{ kind: "directive", type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: TextReadComponent, decorators: [{
            type: Component,
            args: [{ selector: 'text-read', template: "<ng-container *ngIf=\"rowHeight && speed && !revealed\">\r\n  <div #overlay class=\"overlay\">\r\n    <div class=\"container\">\r\n      <div *ngFor=\"let rowIndex of rows\" [style.height.px]=\"rowHeight\" [style.top.px]=\"rowHeight * rowIndex\"\r\n        [style.animationDuration]=\"(speed / rows.length) + 'ms'\"\r\n        [style.animationDelay]=\"(speed * rowIndex / rows.length) + 'ms'\" [classList]=\"overlayClass + ' row'\">\r\n        <div *ngIf=\"!hideCursor\" [style.animationDuration]=\"(speed / rows.length / 40) + 'ms'\"\r\n          [classList]=\"cursorClass + ' row-cursor'\"></div>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</ng-container>\r\n", styles: ["@keyframes read{0%{width:100%}to{width:0}}@keyframes blink{0%{opacity:0}to{opacity:1}}.overlay-black{background-color:#000}.overlay{position:absolute;left:0;top:0;z-index:1;width:100%;height:100%}.container{position:relative;overflow:hidden;width:100%;height:100%}.row{position:absolute;right:0;z-index:1;width:calc(100% + 2px)}.reveal .row{width:0}.read .row{animation-name:read;animation-timing-function:linear;animation-fill-mode:forwards}.cursor-white{background:white}.row-cursor{width:2px;height:100%;animation-name:blink;animation-timing-function:linear;animation-iteration-count:infinite}\n"] }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }]; }, propDecorators: { hideCursor: [{
                type: Input
            }], cursorClass: [{
                type: Input
            }], overlayClass: [{
                type: Input
            }], relativeTo: [{
                type: Input
            }], rowHeight: [{
                type: Input
            }], speed: [{
                type: Input
            }], textLength: [{
                type: Input
            }], overlay: [{
                type: ViewChild,
                args: ['overlay', { static: false }]
            }] } });

class TextAnimationModule {
}
TextAnimationModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: TextAnimationModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
TextAnimationModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.0", ngImport: i0, type: TextAnimationModule, declarations: [TextDisplayComponent,
        TextReadComponent,
        TextScrollDirective], imports: [CommonModule], exports: [TextDisplayComponent,
        TextReadComponent,
        TextScrollDirective] });
TextAnimationModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: TextAnimationModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: TextAnimationModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        TextDisplayComponent,
                        TextReadComponent,
                        TextScrollDirective
                    ],
                    imports: [
                        CommonModule
                    ],
                    exports: [
                        TextDisplayComponent,
                        TextReadComponent,
                        TextScrollDirective
                    ]
                }]
        }] });

/*
 * Public API Surface of ngx-text-animation
 */

/**
 * Generated bundle index. Do not edit.
 */

export { TextAnimationModule, TextDisplayComponent, TextReadComponent, TextScrollDirective };
//# sourceMappingURL=ngx-text-animation.mjs.map
